@@ -373,3 +373,35 @@ class Canvas(tkinter.Canvas):
         for val in range(0, len(coords), 2):
             res.append(self.rget_cor(res[val], res[val+1]))
         return res
+
+    def render_axis(self, color="black", size=.8, label=True, arrowLen=10):
+        """draw the x and y axi of the coordinate system
+
+            @param x: the color of the axi
+            @param size: how many percent schould be ocupied
+            @type size: float greater 0 and les than or equal to 1
+            @param label: wheather or not the axisis schould be labeld
+            @type label: bool
+            @param arrowLen: defiens how long the little arrows at the end are if they have a len of les than 0 the wont be renederd
+            @type arrowLen: int
+            """
+        if not type(size) is float: raise TypeError(f"param size must be float not {type(size)}")
+        if not type(label) is bool: raise TypeError(f"param label must be bool not {type(label)}")
+        if not type(arrowLen) is int: raise TypeError(f"param arrowLen must be int not {type(arrowLen)}")
+        if size > 1: raise ValueError(f"param size must be less than 1")
+        width, hight = self.winfo_reqwidth(), self.winfo_reqheight()
+        self.create_line(-self.origin[0]*size, 0, (width-self.origin[0])*size, 0, color=color)
+        self.create_line(0, -self.origin[1]*size, 0, (hight-self.origin[1])*size, color=color)
+        if arrowLen > 0:
+            # x arrow
+
+            self.create_line((width-self.origin[0])*size, 0, (width-self.origin[0])*size-arrowLen, -arrowLen, color=color)
+            self.create_line((width-self.origin[0])*size, 0, (width-self.origin[0])*size-arrowLen,  arrowLen, color=color)
+
+            #y arrow
+            self.create_line(0, (hight-self.origin[1])*size, -arrowLen, (hight-self.origin[1])*size-arrowLen, color=color)
+            self.create_line(0, (hight-self.origin[1])*size,  arrowLen, (hight-self.origin[1])*size-arrowLen, color=color)
+        
+        if label:
+            self.create_text(-10, (hight-self.origin[1])*size-15,text="x", fill=color)
+            self.create_text((width-self.origin[1])*size-15, -10,text="y", fill=color)
\ No newline at end of file
